pub struct DaemonConfig { /* private fields */ }Expand description
Daemon configuration for a single RMUX server instance.
Implementations
Sourceimpl DaemonConfig
impl DaemonConfig
Sourcepub fn new(socket_path: PathBuf) -> Self
pub fn new(socket_path: PathBuf) -> Self
Builds a daemon configuration for the given socket path.
Sourcepub fn with_default_socket_path() -> Result<Self>
pub fn with_default_socket_path() -> Result<Self>
Builds a daemon configuration using the default spec socket path.
Sourcepub fn socket_path(&self) -> &Path
pub fn socket_path(&self) -> &Path
Returns the configured local IPC endpoint path.
Sourcepub const fn config_load(&self) -> &ConfigLoadOptions
pub const fn config_load(&self) -> &ConfigLoadOptions
Returns the startup config loading policy.
Sourcepub fn subscription_limits(&self) -> SubscriptionLimits
pub fn subscription_limits(&self) -> SubscriptionLimits
Returns the pane-output subscription limits.
Sourcepub fn with_default_config_load(self, quiet: bool, cwd: Option<PathBuf>) -> Self
pub fn with_default_config_load(self, quiet: bool, cwd: Option<PathBuf>) -> Self
Enables RMUX default startup config loading.
Sourcepub fn with_subscription_limits(
self,
subscription_limits: SubscriptionLimits,
) -> Self
pub fn with_subscription_limits( self, subscription_limits: SubscriptionLimits, ) -> Self
Overrides pane-output subscription limits for this daemon.