pub struct DaemonConfig { /* private fields */ }Expand description
Daemon configuration for a single RMUX server instance.
Implementations
Sourceimpl DaemonConfig
impl DaemonConfig
Sourcepub fn new(socket_path: PathBuf) -> Self
pub fn new(socket_path: PathBuf) -> Self
Builds a daemon configuration for the given socket path.
Sourcepub fn with_default_socket_path() -> Result<Self>
pub fn with_default_socket_path() -> Result<Self>
Builds a daemon configuration using the default spec socket path.
Sourcepub fn socket_path(&self) -> &Path
pub fn socket_path(&self) -> &Path
Returns the configured local IPC endpoint path.
Sourcepub const fn config_load(&self) -> &ConfigLoadOptions
pub const fn config_load(&self) -> &ConfigLoadOptions
Returns the startup config loading policy.
Sourcepub fn subscription_limits(&self) -> SubscriptionLimits
pub fn subscription_limits(&self) -> SubscriptionLimits
Returns the pane-output subscription limits.
Sourcepub const fn web_port_explicit(&self) -> bool
pub const fn web_port_explicit(&self) -> bool
Returns whether the web-share listener port was explicitly configured.
Sourcepub const fn web_required(&self) -> bool
pub const fn web_required(&self) -> bool
Returns whether this daemon startup requires the web listener to bind.
Sourcepub fn web_frontend(&self) -> Option<&str>
pub fn web_frontend(&self) -> Option<&str>
Returns the optional external web-share frontend origin.
Sourcepub fn with_default_config_load(self, quiet: bool, cwd: Option<PathBuf>) -> Self
pub fn with_default_config_load(self, quiet: bool, cwd: Option<PathBuf>) -> Self
Enables RMUX default startup config loading.
Sourcepub fn with_subscription_limits(
self,
subscription_limits: SubscriptionLimits,
) -> Self
pub fn with_subscription_limits( self, subscription_limits: SubscriptionLimits, ) -> Self
Overrides pane-output subscription limits for this daemon.
Sourcepub const fn with_web_port(self, port: u16) -> Self
pub const fn with_web_port(self, port: u16) -> Self
Overrides the web-share listener port.
Sourcepub fn with_web_frontend(self, frontend: String) -> Self
pub fn with_web_frontend(self, frontend: String) -> Self
Overrides the frontend origin used in generated web-share URLs.
Sourcepub fn with_config_files(
self,
files: Vec<PathBuf>,
quiet: bool,
cwd: Option<PathBuf>,
) -> Self
pub fn with_config_files( self, files: Vec<PathBuf>, quiet: bool, cwd: Option<PathBuf>, ) -> Self
Enables explicit -f startup config loading.
Sourcepub const fn with_startup_ready_fd(self, ready_fd: i32) -> Self
pub const fn with_startup_ready_fd(self, ready_fd: i32) -> Self
Signals this inherited Linux eventfd after the daemon listener is bound.